@@ -2,11 +2,10 @@ import pandas as pd
 import numpy as np
 import datetime, random
 
-__version__ = '0.3.3' # master file
+__version__ = '0.3.5' # master file
 
 class AKIFlagger:
-    ''' Main flagger to detect patients with acute kidney injury (AKI).
-    This flagger returns patients with AKI according to the `KDIGO guidelines <https://kdigo.org/guidelines/>`_ on changes in creatinine\*. The KDIGO guidelines are as follows:
+    ''' Main flagger to detect patients with acute kidney injury (AKI). This flagger returns patients with AKI according to the `KDIGO guidelines <https://kdigo.org/guidelines/>`_ on changes in creatinine\*. The KDIGO guidelines are as follows:
 
         * *Stage 1:* 0.3 mg/dL increase in serum creatinine in < 48 hours OR 50% increase in serum creatinine in < 7 days (168 hours)
         * *Stage 2:* 100% increase in (or doubling of) serum creatinine in < 7 days (168 hours)
@@ -50,7 +49,7 @@ class AKIFlagger:
         
     '''
     def __init__(self, patient_id = 'patient_id', creatinine = 'creatinine', time = 'time', inpatient = 'inpatient', # Required columns
-                 encounter_id = 'enc', admission = 'admission', baseline_creat = 'baseline_creat', # Helpful columns, imputed otherwise
+                 encounter_id = 'encounter_id', admission = 'admission', baseline_creat = 'baseline_creat', # Helpful columns, imputed otherwise
                  age = 'age', sex = 'sex', race = 'race',  # Required if CKD-EPI imputation is wanted
                  padding = None, HB_trumping = False, eGFR_impute = False, # Main parameters
                  cond1time = '48hours', cond2time = '168hours', pad1time = '0hours', pad2time = '0hours', # Rolling window sizes
@@ -177,16 +176,17 @@ class AKIFlagger:
             aki = pd.Series(stage3.add(stage2.add(stage1*1)), name = 'aki')
             
             # Calculate historical baseline conditions
-            stage1hb = np.round(df[mask][self.creatinine], decimals=4) >= np.round(1.5*baseline_creat[mask], decimals=4)
+            c1hb = np.round(df[mask][self.creatinine], decimals=4) >= np.round(0.3 + baseline_creat[mask], decimals=4)
+            c2hb = np.round(df[mask][self.creatinine], decimals=4) >= np.round(1.5*baseline_creat[mask], decimals=4)
+            stage1hb = np.logical_or(c1hb, c2hb)
             stage2hb = np.round(df[mask][self.creatinine], decimals=4) >= np.round(2*baseline_creat[mask], decimals=4)
             stage3hb = np.round(df[mask][self.creatinine], decimals=4) >= np.round(3*baseline_creat[mask], decimals=4)
             aki[mask]= pd.Series(stage3hb.add(stage2hb.add(stage1hb*1)), name = 'aki')
 
             # Add back in the 0.3 bump criterion (separately since the rolling window is of a different size than the other checks)
-            mask2d = np.logical_and(df.index.get_level_values(level=self.time) >= df[self.admission], df.index.get_level_values(level=self.time) <= df[self.admission] + self.cond1time)
             mask_empty = aki == 0 # Replace the current value only if the flagger didn't flag as baseline. If it was 1, same result. If it was 2 or 3, we would prioritize those over the 0.3 bump
             mask_rw = np.logical_or(np.logical_and(~mask2d, mask_empty), ~mask_bc) # The full mask is of all these conditions: admit to +2d, missed flagger, and non-null baseline creatinine values
-            aki[mask_rw] = c1*1
+            aki[mask_rw] = c1[mask_rw]*1
 
         else: # Vanilla rolling minimum if no HB trumping
 
@@ -205,7 +205,7 @@ class AKIFlagger:
     
     def addAdmissionColumn(self, df, add_encounter_col = None):
         '''
-        Returns the admission (and possible encounter) column(s) in case the patient data frame is missing the admission/enc column.
+        Returns the admission (and possibly encounter) column(s) in case the patient data frame is missing the admission/enc column.
         '''
         pat_gb = df.groupby(self.patient_id, sort = False)
 
@@ -329,7 +329,7 @@ def generate_toy_data(num_patients = 100, num_encounters_range = (1, 3), num_tim
         d1 = pd.DataFrame([mrns, admns, creats]).T
         d2 = pd.DataFrame(encs)
 
-        patient_id, encounter_id, time, admission, inpatient, creatinine, baseline_creat = 'mrn','enc','time','admission','inpatient', 'creat', 'baseline_creat'
+        patient_id, encounter_id, time, admission, inpatient, creatinine, baseline_creat = 'patient_id','encounter_id','time','admission','inpatient', 'creat', 'baseline_creat'
         d1.columns = [patient_id, admission, baseline_creat]
         d2 = d2.add_prefix('enc_')
 
@@ -343,6 +343,7 @@ def generate_toy_data(num_patients = 100, num_encounters_range = (1, 3), num_tim
 
         df1 = pd.concat([d1, d2], axis=1)
         df1 = pd.melt(df1, id_vars = d1.columns, value_name = 'enc').drop('variable', axis=1)
+        df1 = df1.rename(columns={'enc': 'encounter_id'})
         df1 = df1[np.logical_and(~df1[encounter_id].isnull(), ~df1[encounter_id].duplicated())].reset_index(drop=True)
         
         time_deltas = [random.choices(time_delta_range, k=np.random.randint(num_time_range[0],num_time_range[1])) for i in range(df1.shape[0])]
